package net.wanji.datacenter.pojo.convert;

import net.wanji.databus.po.*;
import net.wanji.datacenter.pojo.dto.LanePeriodicDataDTO;
import org.springframework.stereotype.Component;

import java.util.Date;

/**
 * @author duanruiming
 * @date 2023/03/11 14:04
 */
@SuppressWarnings("all")
@Component
public class LanePeriodicDataEventListConvert {
    
    public CrossDataRealtimePO convert2CrossDataRealTimePO(LanePeriodicDataDTO.EventList eventList, CrossBaseLaneInfoPO laneInfoPO) {
        String id = laneInfoPO.getId();
        String crossId = laneInfoPO.getCrossId();
        // todo 路口状态
        int trafficFlow = eventList.getTrafficFlow();
        double meanV = eventList.getMeanV();
        double staticQueueLengthMax = eventList.getStaticQueueLengthMax();
        double stopTimes = eventList.getMeanStopsNumber();
        double meanDelay = eventList.getMeanDelay();
        Integer meanDelayInt = Double.valueOf(meanDelay).intValue();
        double laneSaturation = eventList.getLaneSaturation();
        Date now = new Date();
        int batchTime = (int)now.getTime();
        String dir = String.valueOf(laneInfoPO.getDir());

        CrossDataRealtimePO crossDataRealTimePO = new CrossDataRealtimePO();
        crossDataRealTimePO.setCrossId(crossId);
        crossDataRealTimePO.setStatus(0000); // 路口状态
        crossDataRealTimePO.setType(1); // 1常规 2异常
        crossDataRealTimePO.setStartTime(now);
        crossDataRealTimePO.setDuration(5); // todo 通过第二批次判断

        crossDataRealTimePO.setIsUnbalance(0);
        crossDataRealTimePO.setUnbalanceIndex(1.0);
        crossDataRealTimePO.setUnbalanceDirs(dir);
        crossDataRealTimePO.setIsCongestion(0);
        crossDataRealTimePO.setCongestionIndex(1.0);
        crossDataRealTimePO.setCongestionDirs(dir);
        crossDataRealTimePO.setIsSpillover(0);
        crossDataRealTimePO.setSpilloverIndex(1.0);
        crossDataRealTimePO.setSpilloverDirs(dir);

        crossDataRealTimePO.setTrafficIndex(1.0);// 交通指数
        crossDataRealTimePO.setFlow(trafficFlow);
        crossDataRealTimePO.setFlowRate(Double.valueOf(trafficFlow / 5 * 60));
        crossDataRealTimePO.setSpeed(meanV);
        crossDataRealTimePO.setQueueLength(staticQueueLengthMax);
        crossDataRealTimePO.setStopTimes(stopTimes);
        crossDataRealTimePO.setDelayTime(meanDelayInt);
        crossDataRealTimePO.setSturation(laneSaturation);
        crossDataRealTimePO.setBatchTime(batchTime);
        crossDataRealTimePO.setGmtCreate(now);
        crossDataRealTimePO.setGmtModified(now);
        return crossDataRealTimePO;
    }

    public CrossDirDataRealtimePO convert2CrossDirDataRealTimePO(LanePeriodicDataDTO.EventList eventList, CrossBaseLaneInfoPO laneInfoPO) {
        String crossId = laneInfoPO.getCrossId();
        // todo 路口状态
        int trafficFlow = eventList.getTrafficFlow();
        double meanV = eventList.getMeanV();
        double staticQueueLengthMax = eventList.getStaticQueueLengthMax();
        double stopTimes = eventList.getMeanStopsNumber();
        double meanDelay = eventList.getMeanDelay();
        Integer meanDelayInt = Double.valueOf(meanDelay).intValue();
        double laneSaturation = eventList.getLaneSaturation();
        Date now = new Date();
        int batchTime = (int)now.getTime();
        Integer dir = laneInfoPO.getDir();
        Integer type = laneInfoPO.getType();

        CrossDirDataRealtimePO crossDirDataRealTimePO = new CrossDirDataRealtimePO();
        // 路口方向ID（路口ID_方向_进出口_主辅路序号）
        crossDirDataRealTimePO.setId(String.valueOf(dir).concat(String.valueOf(type)));
        crossDirDataRealTimePO.setDirType(dir);
        crossDirDataRealTimePO.setInOutType(type);
        crossDirDataRealTimePO.setCrossId(crossId);
        crossDirDataRealTimePO.setLength(staticQueueLengthMax);
        crossDirDataRealTimePO.setStatus(0000);
        crossDirDataRealTimePO.setTrafficIndex(0000.00);
        crossDirDataRealTimePO.setStartTime(now);
        crossDirDataRealTimePO.setCapacity(trafficFlow);
        crossDirDataRealTimePO.setDuration(0000);
        crossDirDataRealTimePO.setFlow(trafficFlow);
        crossDirDataRealTimePO.setSpeed(meanV);
        crossDirDataRealTimePO.setQueueLength(staticQueueLengthMax);
        crossDirDataRealTimePO.setStopTimes(stopTimes);
        crossDirDataRealTimePO.setDelayTime(meanDelayInt);
        crossDirDataRealTimePO.setSturation(laneSaturation);
        crossDirDataRealTimePO.setBatchTime(batchTime);
        crossDirDataRealTimePO.setGmtCreate(now);
        crossDirDataRealTimePO.setGmtModified(now);//
        crossDirDataRealTimePO.setEffusionRate(0000.0);//
        return crossDirDataRealTimePO;
    }

    public CrossTurnDataRealtimePO convert2CrossTurnDataRealtimePO(LanePeriodicDataDTO.EventList eventList, CrossBaseLaneInfoPO laneInfoPO) {
        String crossId = laneInfoPO.getCrossId();
        // todo 路口状态
        int trafficFlow = eventList.getTrafficFlow();
        double meanV = eventList.getMeanV();
        double staticQueueLengthMax = eventList.getStaticQueueLengthMax();
        double stopTimes = eventList.getMeanStopsNumber();
        double meanDelay = eventList.getMeanDelay();
        Integer meanDelayInt = Double.valueOf(meanDelay).intValue();
        double laneSaturation = eventList.getLaneSaturation();
        Date now = new Date();
        int batchTime = (int)now.getTime();
        Integer dir = laneInfoPO.getDir();
        Integer type = laneInfoPO.getType();
        Integer turn = laneInfoPO.getTurn();

        CrossTurnDataRealtimePO crossTurnDataRealtimePO = new CrossTurnDataRealtimePO();
        crossTurnDataRealtimePO.setId( crossId.concat("").concat(String.valueOf(turn)));
        crossTurnDataRealtimePO.setTurnType("");
        crossTurnDataRealtimePO.setInDir(0000);
        crossTurnDataRealtimePO.setOutDir(0000);
        crossTurnDataRealtimePO.setCrossId(crossId);
        crossTurnDataRealtimePO.setFlow(trafficFlow);
        crossTurnDataRealtimePO.setStatus(00000);
        crossTurnDataRealtimePO.setTrafficIndex(0000.0);
        crossTurnDataRealtimePO.setSpeed(meanV);
        crossTurnDataRealtimePO.setInSpeed(0000.0);
        crossTurnDataRealtimePO.setOutSpeed(0000.0);
        crossTurnDataRealtimePO.setQueueLength(staticQueueLengthMax);
        crossTurnDataRealtimePO.setStopTimes(stopTimes);
        crossTurnDataRealtimePO.setDelayTime(meanDelayInt);
        crossTurnDataRealtimePO.setSturation(laneSaturation);
        crossTurnDataRealtimePO.setVehheadDist(0000.0);
        crossTurnDataRealtimePO.setVehheadTime(0000.0);
        crossTurnDataRealtimePO.setQuality(0000.0);
        crossTurnDataRealtimePO.setBatchTime(batchTime);
        crossTurnDataRealtimePO.setGmtCreate(now);
        crossTurnDataRealtimePO.setGmtModified(now);
        return crossTurnDataRealtimePO;
    }

    public CrossLaneDataRealTimePO convert2CrossLaneDataRealTimePO(LanePeriodicDataDTO.EventList eventList, CrossBaseLaneInfoPO laneInfoPO) {
        String crossId = laneInfoPO.getCrossId();
        // todo 路口状态
        int trafficFlow = eventList.getTrafficFlow();
        double meanV = eventList.getMeanV();
        double staticQueueLengthMax = eventList.getStaticQueueLengthMax();
        double stopTimes = eventList.getMeanStopsNumber();
        double meanDelay = eventList.getMeanDelay();
        Integer meanDelayInt = Double.valueOf(meanDelay).intValue();
        double laneSaturation = eventList.getLaneSaturation();
        Date now = new Date();
        int batchTime = (int)now.getTime();

        CrossLaneDataRealTimePO crossLaneDataRealTimePO = new CrossLaneDataRealTimePO();
        crossLaneDataRealTimePO.setId(laneInfoPO.getId());
        crossLaneDataRealTimePO.setCrossId(crossId);
        crossLaneDataRealTimePO.setFlow(trafficFlow);
        crossLaneDataRealTimePO.setSpeed(meanV);
        crossLaneDataRealTimePO.setInSpeed(0000.0);
        crossLaneDataRealTimePO.setOutSpeed(0000.0);
        crossLaneDataRealTimePO.setQueueLength(staticQueueLengthMax);
        crossLaneDataRealTimePO.setStopTimes(stopTimes);
        crossLaneDataRealTimePO.setDelayTime(meanDelayInt);
        crossLaneDataRealTimePO.setCapacity(trafficFlow);
        crossLaneDataRealTimePO.setSturation(laneSaturation);
        crossLaneDataRealTimePO.setVehheadTime(0000.0);
        crossLaneDataRealTimePO.setVehheadDist(0000.0);
        crossLaneDataRealTimePO.setQuality(0000.0);
        crossLaneDataRealTimePO.setBatchTime(batchTime);
        crossLaneDataRealTimePO.setGmtCreate(now);
        crossLaneDataRealTimePO.setGmtModified(now);

        return crossLaneDataRealTimePO;
    }
}
